YAML
====

.. versionadded:: 2.0.0

:wp:`YAML` is a common format for web data interchange.

Example:

.. code-block:: yaml

    first-name: "John"
    last-name: "Smith"
    age: 25
    address:
        streetAddress: "21 2nd Street"
        city: "New York"
        state: "NY"
        postalCode: 10021
    phoneNumbers:
        - home: "212 555-1234"
        - fax: "646 555-4567"
